;**************************************************************
;*      
;*	CFU Auswahlrahmen
;*  
;*  Erstellt aus einer Auswahl eine neue Ebene, 
;*  und zeichnet einen Rahmem,
;*  
;*	Geschrieben für GIMP 2.6
;*
;*	Einstellbare Parameter:
;*      
;*  "Rahmenbreite"                        Breite des Rahmen
;*  "Rahmenfarbe"                         Farbe des Rahmen
;*  "Rahmenweichzeichnerradius"           Weichzeichnerradius
;*  "Schlagschatten erstellen:"           Schlagschatten Ja/Nein
;*  "Schattenbreite"                      Schattenbreite
;*  "Schattenhöhe"                        Schattenhöhe
;*  "Schattensichtbarkeit in %"           Schattensichtbarkeit
;*  "Schattenweichzeichnerradius"         Weichzeichnerradius
;*  "Schattenfarbe"                       Schattenfarbe
;*  "Hintergrundbild einfärben"           "Nicht" 
;*                                        "Grau" 
;*                                        "Sepia" 
;*                                        "Farbe" 
;*                                        "Vollfarbe"
;*  "Hintergrundfarbe"                    Hintergrundfarbe
;*  "Hintergrundweichzeichnerradius"      Weichzeichnerradius
;*  "Neues Bild erstellen:"               Neues Bild erzeugen Ja/Nein
;*      
;*	V1.0 vom "29.04.2012"  
;*
;*                                                
;**************************************************************
(define (script-fu-cf_rahmen_auswahl 
						in-Bild
						in-Ebene
						in-RahmenBreite
						in-RahmenFarbe
						in-RahmenWRadius
						in-SollSchatten
						in-SchattenBreite
						in-SchattenHoehe
						in-SchattenSichtbarkeit
						in-SchattenWRadius
						in-SchattenFarbe
						in-BGModus
						in-BGFarbe
            in-BGWRadius
						in-NeuesBild
				)
	(let* (	
					(out-Bild	(cond (	(= in-NeuesBild TRUE)
														(car (gimp-image-duplicate in-Bild)))
													(	(= in-NeuesBild FALSE)
														in-Bild)))
					(org-Ebene	(car (gimp-image-get-active-drawable out-Bild)))
					(BildBreite (car (gimp-image-width out-Bild)))
					(BildHoehe	(car (gimp-image-height out-Bild)))
					(BildTyp    0)
					(BildName 	"CFU - Ebene")
					(bgcolorOrg (car(gimp-palette-get-background)))
					(neue-Ebene 0)
          (schatten-Ebene 0)
          (rahmen-Ebene 0)
          (bild-Ebene 0)
          (farb-Ebene 0)
				)
        
 		(gimp-undo-push-group-start out-Bild)

		(gimp-layer-resize-to-image-size org-Ebene)
    (set! schatten-Ebene (car (gimp-layer-new-from-drawable org-Ebene out-Bild)))
    (if (= (car (gimp-drawable-has-alpha schatten-Ebene)) FALSE)
      (gimp-layer-add-alpha schatten-Ebene)
    )
    (set! rahmen-Ebene (car (gimp-layer-new-from-drawable schatten-Ebene out-Bild)))
    (set! bild-Ebene (car (gimp-layer-new-from-drawable schatten-Ebene out-Bild)))
    
    (gimp-image-add-layer out-Bild schatten-Ebene 0)
    (gimp-image-add-layer out-Bild rahmen-Ebene 0)
    (gimp-image-add-layer out-Bild bild-Ebene 0)
    
    
    (if (= (car (gimp-selection-is-empty out-Bild)) TRUE)
      (gimp-selection-all out-Bild)
    )
    
		(gimp-palette-set-background in-SchattenFarbe)
    (gimp-edit-fill schatten-Ebene BACKGROUND-FILL)
		(gimp-palette-set-background in-RahmenFarbe)
    (gimp-edit-fill rahmen-Ebene BACKGROUND-FILL)
    
    (gimp-selection-invert out-Bild)
    
    (if (= (car (gimp-selection-is-empty out-Bild)) TRUE)
      (begin
        (gimp-selection-all out-Bild)
        (gimp-selection-shrink out-Bild 1)
        (gimp-selection-invert out-Bild)
      )
    )
    
    (gimp-edit-clear schatten-Ebene)
    (gimp-edit-clear rahmen-Ebene)
    (gimp-selection-invert out-Bild)
    (gimp-selection-shrink out-Bild in-RahmenBreite)
    (gimp-selection-invert out-Bild)
    (gimp-edit-clear bild-Ebene)
    (gimp-selection-none out-Bild)
    (gimp-drawable-offset schatten-Ebene FALSE OFFSET-TRANSPARENT in-SchattenBreite in-SchattenHoehe)
    
    (if (> in-RahmenWRadius 0)
      (plug-in-gauss 1 out-Bild rahmen-Ebene in-RahmenWRadius in-RahmenWRadius 1)
    )
       
    (if (> in-SchattenWRadius 0)
      (plug-in-gauss 1 out-Bild schatten-Ebene in-SchattenWRadius in-SchattenWRadius 1)
    )
    (gimp-layer-set-opacity schatten-Ebene in-SchattenSichtbarkeit)
    
    (if (= in-SollSchatten TRUE)
      (begin
        (gimp-image-merge-down out-Bild rahmen-Ebene EXPAND-AS-NECESSARY)
      )
      (begin
        (gimp-image-remove-layer out-Bild schatten-Ebene)
      )
    )

    (set! neue-Ebene (car (gimp-image-merge-down out-Bild bild-Ebene EXPAND-AS-NECESSARY)))
    (gimp-layer-resize-to-image-size neue-Ebene)
    
    (gimp-image-set-active-layer out-Bild org-Ebene)
    
    ( if ( > in-BGModus 0)
      (begin
        (cond ((= in-BGModus 1)
                (begin
                  (set! farb-Ebene (car (gimp-layer-new-from-drawable org-Ebene out-Bild)))
                  (gimp-image-add-layer out-Bild farb-Ebene -1)
                  (gimp-layer-set-mode farb-Ebene COLOR-MODE)
                  (gimp-palette-set-background '(0 0 0))
                  (gimp-edit-fill farb-Ebene BACKGROUND-FILL)
                  (set! org-Ebene (car (gimp-image-merge-down out-Bild farb-Ebene EXPAND-AS-NECESSARY)))
                  (gimp-image-set-active-layer out-Bild org-Ebene)
                )
              )
              ((= in-BGModus 2)
                (begin
                  (set! farb-Ebene (car (gimp-layer-new-from-drawable org-Ebene out-Bild)))
                  (gimp-image-add-layer out-Bild farb-Ebene -1)
                  (gimp-layer-set-mode farb-Ebene COLOR-MODE)
                  (gimp-palette-set-background '(124 78 24))
                  (gimp-edit-fill farb-Ebene BACKGROUND-FILL)
                  (set! org-Ebene (car (gimp-image-merge-down out-Bild farb-Ebene EXPAND-AS-NECESSARY)))
                  (gimp-image-set-active-layer out-Bild org-Ebene)
                )
              )
              ((= in-BGModus 3)
                (begin
                  (set! farb-Ebene (car (gimp-layer-new-from-drawable org-Ebene out-Bild)))
                  (gimp-image-add-layer out-Bild farb-Ebene -1)
                  (gimp-layer-set-mode farb-Ebene COLOR-MODE)
                  (gimp-palette-set-background in-BGFarbe)
                  (gimp-edit-fill farb-Ebene BACKGROUND-FILL)
                  (set! org-Ebene (car (gimp-image-merge-down out-Bild farb-Ebene EXPAND-AS-NECESSARY)))
                  (gimp-image-set-active-layer out-Bild org-Ebene)
                )
              )
              ((= in-BGModus 4)
                (begin
                  (gimp-palette-set-background in-BGFarbe)
                  (gimp-edit-fill org-Ebene BACKGROUND-FILL)
                )
              )
        )
      )
    )
    
    (if (> in-BGWRadius 0)
      (plug-in-gauss 1 out-Bild org-Ebene in-BGWRadius in-BGWRadius 1)
    )
    
		(gimp-undo-push-group-end out-Bild)

 	(if (= in-NeuesBild TRUE)
 		(gimp-display-new out-Bild)
	  )
		(gimp-displays-flush)
		(gimp-palette-set-background bgcolorOrg)	

	) ; let ende
) ;;def ende

 
	(script-fu-register
		"script-fu-cf_rahmen_auswahl"               ;Name der Funktion, die aufgerufen werden soll
		"CFU Auswahlrahmen"                         ;Name des Skripts
		"Erstellt einen Rahmen in einer Auswahl"		;Beschreibung des Skripts
		"CF"                                     	  ;Name des Autors
		"Copyleft by CF"                         	  ;Copyright-Infos
		"29.04.2012"                                ;Datum
		"RGB*"                     	;
		SF-IMAGE "Das Bild" 0
		SF-DRAWABLE "Die Ebene" 0
 		SF-ADJUSTMENT "Rahmenbreite"     '(5 0 999 1 10 0 0)
 		SF-COLOR "Rahmenfarbe" '(255 255 255)
 		SF-ADJUSTMENT "Rahmenweichzeichnerradius"     '(2 0 250 1 10 0 0)
		SF-TOGGLE "Schlagschatten erstellen:" TRUE
 		SF-ADJUSTMENT "Schattenbreite"     '(3 -999 999 1 10 0 0)
 		SF-ADJUSTMENT "Schattenhöhe"     '(3 -999 999 1 10 0 0)
 		SF-ADJUSTMENT "Schattensichtbarkeit in %"     '(80 0 100 1 10 0 0)
 		SF-ADJUSTMENT "Schattenweichzeichnerradius"     '(4 0 250 1 10 0 0)
 		SF-COLOR "Schattenfarbe" '(0 0 0)
		SF-OPTION "Hintergrundbild einfärben"     '("Nicht" "Grau" "Sepia" "Farbe" "Vollfarbe")
 		SF-COLOR "Hintergrundfarbe" '(255 132 0)
 		SF-ADJUSTMENT "Hintergrundweichzeichnerradius"     '(0 0 250 1 10 0 0)
		SF-TOGGLE     "Neues Bild erstellen:" TRUE
	)

	(script-fu-menu-register "script-fu-cf_rahmen_auswahl" "<Image>/CFU/Rahmen")		
